==> haskell-singleton-bool-0.1.8-45.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-singleton-bool.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 singleton-bool
version:              0.1.8
visibility:           public
id:                   singleton-bool-0.1.8-FBR3WTqmpe756ZKoVuyK7L
key:                  singleton-bool-0.1.8-FBR3WTqmpe756ZKoVuyK7L
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/singleton-bool#readme
synopsis:             Type level booleans
description:
    Type level booleans.

    @singletons@ package provides similar functionality,
    but it has tight dependency constraints.

category:             Dependent Types
abi:                  385eedb6ad77bcfd9d89234eb1de02d1
exposed:              True
exposed-modules:      Data.Singletons.Bool
import-dirs:          /usr/lib/ghc-9.6.6/site-local/singleton-bool-0.1.8
library-dirs:         /usr/lib/ghc-9.6.6/site-local/singleton-bool-0.1.8
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/singleton-bool-0.1.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-singleton-bool
hs-libraries:         HSsingleton-bool-0.1.8-FBR3WTqmpe756ZKoVuyK7L
depends:
    base-4.18.2.1 boring-0.2.2-2aq1ciWPNkQB31v6aiIRKA
    dec-0.0.6-263DLNY3k7iJhcZSv4mNkm deepseq-1.4.8.1
    some-1.0.6-1FUKmKhhCiB9O9TtG7osbe

haddock-interfaces:
    /usr/share/doc/haskell-singleton-bool/html/singleton-bool.haddock

haddock-html:         /usr/share/doc/haskell-singleton-bool/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-singleton-bool-0.1.8-47-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-singleton-bool.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 singleton-bool
version:              0.1.8
visibility:           public
id:                   singleton-bool-0.1.8-H3qvqKJA8XhBKTQ3qxZcTi
key:                  singleton-bool-0.1.8-H3qvqKJA8XhBKTQ3qxZcTi
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/singleton-bool#readme
synopsis:             Type level booleans
description:
    Type level booleans.

    @singletons@ package provides similar functionality,
    but it has tight dependency constraints.

category:             Dependent Types
abi:                  dbffd23e6e9fc110ce259d8e701f370f
exposed:              True
exposed-modules:      Data.Singletons.Bool
import-dirs:          /usr/lib/ghc-9.6.6/site-local/singleton-bool-0.1.8
library-dirs:         /usr/lib/ghc-9.6.6/site-local/singleton-bool-0.1.8
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/singleton-bool-0.1.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-singleton-bool
hs-libraries:         HSsingleton-bool-0.1.8-H3qvqKJA8XhBKTQ3qxZcTi
depends:
    base-4.18.2.1 boring-0.2.2-2aq1ciWPNkQB31v6aiIRKA
    dec-0.0.6-263DLNY3k7iJhcZSv4mNkm deepseq-1.4.8.1
    some-1.0.6-APNUyWBz8dU4KJ0cJBNGqi

haddock-interfaces:
    /usr/share/doc/haskell-singleton-bool/html/singleton-bool.haddock

haddock-html:         /usr/share/doc/haskell-singleton-bool/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
